( cd usr/share/doc/HTML/ca/klettres ; rm -rf common )
( cd usr/share/doc/HTML/ca/klettres ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kontact ; rm -rf common )
( cd usr/share/doc/HTML/ca/kontact ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/PolicyKit-kde ; rm -rf common )
( cd usr/share/doc/HTML/ca/PolicyKit-kde ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/klipper ; rm -rf common )
( cd usr/share/doc/HTML/ca/klipper ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/systemsettings ; rm -rf common )
( cd usr/share/doc/HTML/ca/systemsettings ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kdesu ; rm -rf common )
( cd usr/share/doc/HTML/ca/kdesu ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/khangman ; rm -rf common )
( cd usr/share/doc/HTML/ca/khangman ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kontact-admin ; rm -rf common )
( cd usr/share/doc/HTML/ca/kontact-admin ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/knode ; rm -rf common )
( cd usr/share/doc/HTML/ca/knode ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kuser ; rm -rf common )
( cd usr/share/doc/HTML/ca/kuser ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kdm ; rm -rf common )
( cd usr/share/doc/HTML/ca/kdm ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/konsole ; rm -rf common )
( cd usr/share/doc/HTML/ca/konsole ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/ca/kdepasswd ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kfind ; rm -rf common )
( cd usr/share/doc/HTML/ca/kfind ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kalzium ; rm -rf common )
( cd usr/share/doc/HTML/ca/kalzium ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/amor ; rm -rf common )
( cd usr/share/doc/HTML/ca/amor ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/akregator ; rm -rf common )
( cd usr/share/doc/HTML/ca/akregator ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmix ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmix ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/lokalize ; rm -rf common )
( cd usr/share/doc/HTML/ca/lokalize ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kwatchgnupg ; rm -rf common )
( cd usr/share/doc/HTML/ca/kwatchgnupg ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/sweeper ; rm -rf common )
( cd usr/share/doc/HTML/ca/sweeper ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/ca/kwrite ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmag ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmag ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kjots ; rm -rf common )
( cd usr/share/doc/HTML/ca/kjots ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/blinken ; rm -rf common )
( cd usr/share/doc/HTML/ca/blinken ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/file ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/file ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/network ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/network ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/nepomuksearch ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/nepomuksearch ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/cgi ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/cgi ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/smb ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/smb ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/bookmarks ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/bookmarks ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/rlogin ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/tar ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/tar ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/finger ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/finger ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/imap ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/imap ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/floppy ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/floppy ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/http ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/http ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/mbox ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/mbox ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/mailto ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/mailto ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/xz ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/xz ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/sftp ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/sftp ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/telnet ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/telnet ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/pop3 ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/gzip ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/gzip ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/news ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/news ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/thumbnail ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/bzip2 ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/bzip2 ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/audiocd ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/audiocd ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/smtp ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/smtp ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/nfs ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/nfs ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/ldap ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/ldap ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/help ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/help ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/data ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/data ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/info ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/info ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/fish ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/fish ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/nntp ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/nntp ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/ftp ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/ftp ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/man ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/man ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/webdav ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/webdav ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kioslave/sieve ; rm -rf common )
( cd usr/share/doc/HTML/ca/kioslave/sieve ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcron ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcron ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kstars ; rm -rf common )
( cd usr/share/doc/HTML/ca/kstars ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kfontview ; rm -rf common )
( cd usr/share/doc/HTML/ca/kfontview ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kgeography ; rm -rf common )
( cd usr/share/doc/HTML/ca/kgeography ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmenuedit ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/ksysguard ; rm -rf common )
( cd usr/share/doc/HTML/ca/ksysguard ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/korganizer ; rm -rf common )
( cd usr/share/doc/HTML/ca/korganizer ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/jovie ; rm -rf common )
( cd usr/share/doc/HTML/ca/jovie ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/onlinehelp ; rm -rf common )
( cd usr/share/doc/HTML/ca/onlinehelp ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmouth ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmouth ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/printer-applet ; rm -rf common )
( cd usr/share/doc/HTML/ca/printer-applet ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcharselect ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcharselect ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/cervisia ; rm -rf common )
( cd usr/share/doc/HTML/ca/cervisia ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kturtle ; rm -rf common )
( cd usr/share/doc/HTML/ca/kturtle ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/ca/kwallet ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kabcclient ; rm -rf common )
( cd usr/share/doc/HTML/ca/kabcclient ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kate ; rm -rf common )
( cd usr/share/doc/HTML/ca/kate ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-hardware ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-hardware ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/cookies ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/blockdevices ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kded ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kded ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/splashscreen ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/splashscreen ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/screensaver ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/screensaver ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/spellchecking ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/phonon ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/phonon ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/multiplemonitors ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/multiplemonitors ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/mouse ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/mouse ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/desktop ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/desktop ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-actions ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-actions ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/icons ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/icons ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-java-js ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-java-js ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/bell ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/bell ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/proxy ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/smb ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/smb ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kwintabbox ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kwintabbox ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/workspaceoptions ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/workspaceoptions ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/bookmarks ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/bookmarks ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/trash ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/trash ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmaccess ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmaccess ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/fonts ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/fonts ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/cddbretrieval ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/cddbretrieval ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kgamma ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kgamma ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/joystick ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/joystick ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khotkeys ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khotkeys ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kwindecoration ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kwindecoration ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/desktopthemedetails ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/desktopthemedetails ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/netpref ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kresources ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kresources ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmsmserver ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/attica ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/attica ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/language ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/language ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmcss ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/colors ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/colors ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmcgi ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmcgi ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-adblock ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-adblock ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/history ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/history ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/powerdevil ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/powerdevil ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kwinscreenedges ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kwinscreenedges ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-plugins ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-plugins ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kremotecontrol ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kremotecontrol ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/componentchooser ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/componentchooser ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcm_ssl ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcm_ssl ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmstyle ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmstyle ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmnotify ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/paths ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/paths ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/keys ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/keys ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/clock ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/clock ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/windowbehaviour ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/windowbehaviour ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-device-automounter ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/solid-device-automounter ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/autostart ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/autostart ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/useragent ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kamera ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kamera ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/ebrowsing ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/cache ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/cache ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kwincompositing ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kwincompositing ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/filemanager ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-behavior ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-behavior ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/emoticons ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/emoticons ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/windowspecific ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/windowspecific ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/fontinst ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/fontinst ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/cursortheme ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/cursortheme ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/nepomuk ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/nepomuk ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/filetypes ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/performance ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/performance ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-general ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/khtml-general ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/share/doc/HTML/ca/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/ktimetracker ; rm -rf common )
( cd usr/share/doc/HTML/ca/ktimetracker ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/katomic ; rm -rf common )
( cd usr/share/doc/HTML/ca/katomic ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kleopatra ; rm -rf common )
( cd usr/share/doc/HTML/ca/kleopatra ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/system-config-printer-kde ; rm -rf common )
( cd usr/share/doc/HTML/ca/system-config-printer-kde ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/ca/ktouch ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/dolphin ; rm -rf common )
( cd usr/share/doc/HTML/ca/dolphin ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kget ; rm -rf common )
( cd usr/share/doc/HTML/ca/kget ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/khelpcenter/documentationnotfound ; rm -rf common )
( cd usr/share/doc/HTML/ca/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/khelpcenter ; rm -rf common )
( cd usr/share/doc/HTML/ca/khelpcenter ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/khelpcenter/glossary ; rm -rf common )
( cd usr/share/doc/HTML/ca/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmousetool ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmousetool ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/ca/kwordquiz ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/krfb ; rm -rf common )
( cd usr/share/doc/HTML/ca/krfb ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kinfocenter ; rm -rf common )
( cd usr/share/doc/HTML/ca/kinfocenter ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kalarm ; rm -rf common )
( cd usr/share/doc/HTML/ca/kalarm ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/bomber ; rm -rf common )
( cd usr/share/doc/HTML/ca/bomber ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/umbrello ; rm -rf common )
( cd usr/share/doc/HTML/ca/umbrello ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/plasma-desktop ; rm -rf common )
( cd usr/share/doc/HTML/ca/plasma-desktop ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kimagemapeditor ; rm -rf common )
( cd usr/share/doc/HTML/ca/kimagemapeditor ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/blogilo ; rm -rf common )
( cd usr/share/doc/HTML/ca/blogilo ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/krdc ; rm -rf common )
( cd usr/share/doc/HTML/ca/krdc ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kdf ; rm -rf common )
( cd usr/share/doc/HTML/ca/kdf ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kdebugdialog ; rm -rf common )
( cd usr/share/doc/HTML/ca/kdebugdialog ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/ca/kbruch ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/sonnet ; rm -rf common )
( cd usr/share/doc/HTML/ca/sonnet ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/konsolekalendar ; rm -rf common )
( cd usr/share/doc/HTML/ca/konsolekalendar ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/ca/konqueror ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kapptemplate ; rm -rf common )
( cd usr/share/doc/HTML/ca/kapptemplate ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/ca/kgpg ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kmail ; rm -rf common )
( cd usr/share/doc/HTML/ca/kmail ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/ksystemlog ; rm -rf common )
( cd usr/share/doc/HTML/ca/ksystemlog ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kompare ; rm -rf common )
( cd usr/share/doc/HTML/ca/kompare ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/ktimer ; rm -rf common )
( cd usr/share/doc/HTML/ca/ktimer ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/kteatime ; rm -rf common )
( cd usr/share/doc/HTML/ca/kteatime ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/knetattach ; rm -rf common )
( cd usr/share/doc/HTML/ca/knetattach ; ln -sf /usr/share/doc/HTML/ca//common common )
( cd usr/share/doc/HTML/ca/knotes ; rm -rf common )
( cd usr/share/doc/HTML/ca/knotes ; ln -sf /usr/share/doc/HTML/ca//common common )
